==> react-bootstrap-design-0.3.0.tgz: package/src/index.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import Design from './Design';
import registerServiceWorker from './registerServiceWorker';
import './Design.css';

import Minimal from './configurations/evolution/Minimal'
import MinimalRounded from './configurations/evolution/MinimalRounded'
import MinimalRoundedDetailed from './configurations/evolution/MinimalRoundedDetailed'

import Burst from './configurations/components/Burst'
import IndexComponent from './configurations/components/IndexComponent'
import Hand from './configurations/components/Hand'

import Steel from './configurations/backgrounds/Steel'
import GreyFume from './configurations/backgrounds/GreyFume'

import Chronograph from './configurations/models/Chronograph'
import ColorfulChronoSquare from './configurations/models/ColorfulChronoSquare'
import Panda from './configurations/models/Panda'
import PandaSquare from './configurations/models/PandaSquare'
import SmallSeconds from './configurations/models/SmallSeconds'
import SmallSecondsSquare from './configurations/models/SmallSecondsSquare'
import ColorfulChrono from './configurations/models/ColorfulChrono'

ReactDOM.render(
    <div className="row mb-4">
        <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
            <Design key="Minimal" styles={Minimal} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
            <Design key="MinimalRounded" styles={MinimalRounded} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
            <Design key="MinimalRoundedDetailed" styles={MinimalRoundedDetailed} />
        </div>        
        <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
            <Design key="Chronograph" styles={Chronograph} />
        </div>
    </div>,
    document.getElementById('evolution')
);

ReactDOM.render(
    <div className="row mb-4">
        <div className="col-md-12 col-lg-9">
            <div className="row">
                <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
                    <h3>.index</h3>
                    <Design key="IndexComponent" styles={IndexComponent} />
                </div>
                <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
                    <h3>.hand</h3>
                    <Design key="Hand" styles={Hand} />
                </div>
                <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
                    <h3>.burst</h3>
                    <Design key="Burst" styles={Burst} />
                </div>
            </div>
        </div>
    </div>,
    document.getElementById('components')
);

ReactDOM.render(
    <div className="row mb-4">
        <div className="col-md-12 col-lg-9">
            <div className="row">
                <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
                    <h3>.bg-steel</h3>
                    <Design key="Steel" styles={Steel} />
                </div>
                <div className="col-sm-6 col-md-4 col-lg-3 mb-3">
                    <h3>.bg-grey-fume</h3>
                    <Design key="GreyFume" styles={GreyFume} />
                </div>
            </div>
        </div>
    </div>,
    document.getElementById('backgrounds')
);

ReactDOM.render(
    <div className="row">
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{ColorfulChrono.header}</h4>
            <Design key="ColorfulChrono" styles={ColorfulChrono} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{SmallSecondsSquare.header}</h4>
            <Design key="SmallSecondsSquare" styles={SmallSecondsSquare} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{PandaSquare.header}</h4>
            <Design key="PandaSquare" styles={PandaSquare} />
        </div>        
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{ColorfulChronoSquare.header}</h4>
            <Design key="ColorfulChronoSquare" styles={ColorfulChronoSquare} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{SmallSeconds.header}</h4>
            <Design key="SmallSeconds" styles={SmallSeconds} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{Panda.header}</h4>
            <Design key="Panda" styles={Panda} />
        </div>
    </div>,
    document.getElementById('showcase')
);

registerServiceWorker();

==> react-bootstrap-design-0.4.0.tgz: package/src/index.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import Design from './Design';
import registerServiceWorker from './registerServiceWorker';
import './Design.css';

import Minimal from './configurations/evolution/Minimal';
import MinimalRounded from './configurations/evolution/MinimalRounded';
import MinimalRoundedDetailed from './configurations/evolution/MinimalRoundedDetailed';

import Burst from './configurations/components/Burst';
import IndexComponent from './configurations/components/IndexComponent';
import Hand from './configurations/components/Hand';

import Steel from './configurations/backgrounds/Steel';
import GreyFume from './configurations/backgrounds/GreyFume';

import Chronograph from './configurations/models/Chronograph';
import ColorfulChronoSquare from './configurations/models/ColorfulChronoSquare';
import Panda from './configurations/models/Panda';
import PandaSquare from './configurations/models/PandaSquare';
import SmallSeconds from './configurations/models/SmallSeconds';
import SmallSecondsSquare from './configurations/models/SmallSecondsSquare';
import ColorfulChrono from './configurations/models/ColorfulChrono';

ReactDOM.render(
    <div className="row">
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <Design key="Minimal" styles={Minimal} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <Design key="MinimalRounded" styles={MinimalRounded} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <Design key="MinimalRoundedDetailed" styles={MinimalRoundedDetailed} />
        </div>        
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <Design key="Chronograph" styles={Chronograph} />
        </div>
    </div>,
    document.getElementById('evolution')
);

ReactDOM.render(
    <div className="row">
        <div className="col-md-12 col-lg-9">
            <div className="row">
                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                    <h3>.index</h3>
                    <Design key="IndexComponent" styles={IndexComponent} />
                </div>
                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                    <h3>.hand</h3>
                    <Design key="Hand" styles={Hand} />
                </div>
                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                    <h3>.burst</h3>
                    <Design key="Burst" styles={Burst} />
                </div>
            </div>
        </div>
    </div>,
    document.getElementById('components')
);

ReactDOM.render(
    <div className="row">
        <div className="col-md-12 col-lg-9">
            <div className="row">
                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                    <h3>.bg-steel</h3>
                    <Design key="Steel" styles={Steel} />
                </div>
                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                    <h3>.bg-grey-fume</h3>
                    <Design key="GreyFume" styles={GreyFume} />
                </div>
            </div>
        </div>
    </div>,
    document.getElementById('backgrounds')
);

ReactDOM.render(
    <div className="row">
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{ColorfulChrono.header}</h4>
            <Design key="ColorfulChrono" styles={ColorfulChrono} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{SmallSecondsSquare.header}</h4>
            <Design key="SmallSecondsSquare" styles={SmallSecondsSquare} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{PandaSquare.header}</h4>
            <Design key="PandaSquare" styles={PandaSquare} />
        </div>        
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{ColorfulChronoSquare.header}</h4>
            <Design key="ColorfulChronoSquare" styles={ColorfulChronoSquare} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{SmallSeconds.header}</h4>
            <Design key="SmallSeconds" styles={SmallSeconds} />
        </div>
        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
            <h4 className="text-center">{Panda.header}</h4>
            <Design key="Panda" styles={Panda} />
        </div>
    </div>,
    document.getElementById('showcase')
);

registerServiceWorker();
